@@ -2,6 +2,8 @@
 # -*- coding: utf-8 -*-
 
 class Config:
+  compiler    = "GNU"
+  blasname    = "Unknown"
   blaslib     = ""                # the BLAS library
   cblaslib    = ""                # the CBLAS library
   lapacklib   = ""                # the Lapack library
